# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lmao_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
try:
  from gen.proto import logs_pb2 as logs__pb2
except ImportError:
  from nbox.lmao_v4.proto import logs_pb2 as logs__pb2
try:
  from gen.proto import project_pb2 as project__pb2
except ImportError:
  from nbox.lmao_v4.proto import project_pb2 as project__pb2
try:
  from gen.proto import rules_pb2 as rules__pb2
except ImportError:
  from nbox.lmao_v4.proto import rules_pb2 as rules__pb2
try:
  from gen.proto import tracker_pb2 as tracker__pb2
except ImportError:
  from nbox.lmao_v4.proto import tracker_pb2 as tracker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12lmao_service.proto\x12\x07lmao_pb\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\nlogs.proto\x1a\rproject.proto\x1a\x0brules.proto\x1a\rtracker.proto2\xa9\x10\n\x04LMAO\x12m\n\x0bInitProject\x12\x1b.lmao_pb.InitProjectRequest\x1a\x1c.lmao_pb.InitProjectResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/monitoring/init_project:\x01*\x12T\n\nGetProject\x12\x10.lmao_pb.Project\x1a\x10.lmao_pb.Project\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/monitoring/get_project:\x01*\x12Z\n\rUpdateProject\x12\x10.lmao_pb.Project\x1a\x10.lmao_pb.Project\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/monitoring/update_project:\x01*\x12`\n\rDeleteProject\x12\x10.lmao_pb.Project\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/monitoring/delete_project:\x01*\x12q\n\x0cListProjects\x12\x1c.lmao_pb.ListProjectsRequest\x1a\x1d.lmao_pb.ListProjectsResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/monitoring/list_projects:\x01*\x12\x65\n\x0eGetRuleBuilder\x12\x14.lmao_pb.RuleBuilder\x1a\x14.lmao_pb.RuleBuilder\"\'\x82\xd3\xe4\x93\x02!\"\x1c/monitoring/get_rule_builder:\x01*\x12Y\n\nCreateRule\x12\x18.lmao_pb.InitRuleRequest\x1a\r.lmao_pb.Rule\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/monitoring/create_rule:\x01*\x12H\n\x07GetRule\x12\r.lmao_pb.Rule\x1a\r.lmao_pb.Rule\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/monitoring/get_rule:\x01*\x12N\n\nUpdateRule\x12\r.lmao_pb.Rule\x1a\r.lmao_pb.Rule\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/monitoring/update_rule:\x01*\x12W\n\nDeleteRule\x12\r.lmao_pb.Rule\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/monitoring/delete_rule:\x01*\x12V\n\tListRules\x12\x12.lmao_pb.RulesList\x1a\x12.lmao_pb.RulesList\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/monitoring/list_rules:\x01*\x12\x61\n\x0bInitTracker\x12\x1b.lmao_pb.InitTrackerRequest\x1a\x10.lmao_pb.Tracker\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/monitoring/init_tracker:\x01*\x12T\n\nGetTracker\x12\x10.lmao_pb.Tracker\x1a\x10.lmao_pb.Tracker\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/monitoring/get_tracker:\x01*\x12Z\n\rUpdateTracker\x12\x10.lmao_pb.Tracker\x1a\x10.lmao_pb.Tracker\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/monitoring/update_tracker:\x01*\x12`\n\rDeleteTracker\x12\x10.lmao_pb.Tracker\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/monitoring/delete_tracker:\x01*\x12q\n\x0cListTrackers\x12\x1c.lmao_pb.ListTrackersRequest\x1a\x1d.lmao_pb.ListTrackersResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/monitoring/list_trackers:\x01*\x12s\n\x0fGetTrackerTable\x12\x1f.lmao_pb.GetTrackerTableRequest\x1a\x15.lmao_pb.TrackerTable\"(\x82\xd3\xe4\x93\x02\"\"\x1d/monitoring/get_tracker_table:\x01*\x12\x63\n\rPutTrackerLog\x12\x13.lmao_pb.TrackerLog\x1a\x15.lmao_pb.TrackerLogId\"&\x82\xd3\xe4\x93\x02 \"\x1b/monitoring/put_tracker_log:\x01*\x12r\n\x0eGetTrackerLogs\x12\x1a.lmao_pb.TrackerLogRequest\x1a\x1b.lmao_pb.TrackerLogResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/monitoring/get_tracker_logs:\x01*\x12o\n\rCreateDataset\x12\x1e.lmao_pb.TrackerDatasetRequest\x1a\x17.lmao_pb.TrackerDataset\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/monitoring/create_dataset:\x01*\x12u\n\x13\x43reateDatasetStatus\x12\x17.lmao_pb.TrackerDataset\x1a\x17.lmao_pb.TrackerDataset\",\x82\xd3\xe4\x93\x02&\"!/monitoring/create_dataset_status:\x01*B/Z-github.com/NimbleBoxAI/nimblebox-lmao/lmao_pbb\x06proto3')



_LMAO = DESCRIPTOR.services_by_name['LMAO']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/NimbleBoxAI/nimblebox-lmao/lmao_pb'
  _LMAO.methods_by_name['InitProject']._options = None
  _LMAO.methods_by_name['InitProject']._serialized_options = b'\202\323\344\223\002\035\"\030/monitoring/init_project:\001*'
  _LMAO.methods_by_name['GetProject']._options = None
  _LMAO.methods_by_name['GetProject']._serialized_options = b'\202\323\344\223\002\034\"\027/monitoring/get_project:\001*'
  _LMAO.methods_by_name['UpdateProject']._options = None
  _LMAO.methods_by_name['UpdateProject']._serialized_options = b'\202\323\344\223\002\037\"\032/monitoring/update_project:\001*'
  _LMAO.methods_by_name['DeleteProject']._options = None
  _LMAO.methods_by_name['DeleteProject']._serialized_options = b'\202\323\344\223\002\037\"\032/monitoring/delete_project:\001*'
  _LMAO.methods_by_name['ListProjects']._options = None
  _LMAO.methods_by_name['ListProjects']._serialized_options = b'\202\323\344\223\002\036\"\031/monitoring/list_projects:\001*'
  _LMAO.methods_by_name['GetRuleBuilder']._options = None
  _LMAO.methods_by_name['GetRuleBuilder']._serialized_options = b'\202\323\344\223\002!\"\034/monitoring/get_rule_builder:\001*'
  _LMAO.methods_by_name['CreateRule']._options = None
  _LMAO.methods_by_name['CreateRule']._serialized_options = b'\202\323\344\223\002\034\"\027/monitoring/create_rule:\001*'
  _LMAO.methods_by_name['GetRule']._options = None
  _LMAO.methods_by_name['GetRule']._serialized_options = b'\202\323\344\223\002\031\"\024/monitoring/get_rule:\001*'
  _LMAO.methods_by_name['UpdateRule']._options = None
  _LMAO.methods_by_name['UpdateRule']._serialized_options = b'\202\323\344\223\002\034\"\027/monitoring/update_rule:\001*'
  _LMAO.methods_by_name['DeleteRule']._options = None
  _LMAO.methods_by_name['DeleteRule']._serialized_options = b'\202\323\344\223\002\034\"\027/monitoring/delete_rule:\001*'
  _LMAO.methods_by_name['ListRules']._options = None
  _LMAO.methods_by_name['ListRules']._serialized_options = b'\202\323\344\223\002\033\"\026/monitoring/list_rules:\001*'
  _LMAO.methods_by_name['InitTracker']._options = None
  _LMAO.methods_by_name['InitTracker']._serialized_options = b'\202\323\344\223\002\035\"\030/monitoring/init_tracker:\001*'
  _LMAO.methods_by_name['GetTracker']._options = None
  _LMAO.methods_by_name['GetTracker']._serialized_options = b'\202\323\344\223\002\034\"\027/monitoring/get_tracker:\001*'
  _LMAO.methods_by_name['UpdateTracker']._options = None
  _LMAO.methods_by_name['UpdateTracker']._serialized_options = b'\202\323\344\223\002\037\"\032/monitoring/update_tracker:\001*'
  _LMAO.methods_by_name['DeleteTracker']._options = None
  _LMAO.methods_by_name['DeleteTracker']._serialized_options = b'\202\323\344\223\002\037\"\032/monitoring/delete_tracker:\001*'
  _LMAO.methods_by_name['ListTrackers']._options = None
  _LMAO.methods_by_name['ListTrackers']._serialized_options = b'\202\323\344\223\002\036\"\031/monitoring/list_trackers:\001*'
  _LMAO.methods_by_name['GetTrackerTable']._options = None
  _LMAO.methods_by_name['GetTrackerTable']._serialized_options = b'\202\323\344\223\002\"\"\035/monitoring/get_tracker_table:\001*'
  _LMAO.methods_by_name['PutTrackerLog']._options = None
  _LMAO.methods_by_name['PutTrackerLog']._serialized_options = b'\202\323\344\223\002 \"\033/monitoring/put_tracker_log:\001*'
  _LMAO.methods_by_name['GetTrackerLogs']._options = None
  _LMAO.methods_by_name['GetTrackerLogs']._serialized_options = b'\202\323\344\223\002!\"\034/monitoring/get_tracker_logs:\001*'
  _LMAO.methods_by_name['CreateDataset']._options = None
  _LMAO.methods_by_name['CreateDataset']._serialized_options = b'\202\323\344\223\002\037\"\032/monitoring/create_dataset:\001*'
  _LMAO.methods_by_name['CreateDatasetStatus']._options = None
  _LMAO.methods_by_name['CreateDatasetStatus']._serialized_options = b'\202\323\344\223\002&\"!/monitoring/create_dataset_status:\001*'
  _LMAO._serialized_start=146
  _LMAO._serialized_end=2235
# @@protoc_insertion_point(module_scope)
