# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: project.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rproject.proto\x12\x07lmao_pb\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc3\x02\n\x07Project\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\ntotal_runs\x18\x04 \x01(\x03\x12\x16\n\x0etotal_servings\x18\x05 \x01(\x03\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08relic_id\x18\x08 \x01(\t\x12\x13\n\x0bupdate_keys\x18\t \x03(\t\x12)\n\x08metadata\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cruns_counter\x18\x0b \x01(\x05\x12\x14\n\x0clive_counter\x18\x0c \x01(\x05\"*\n\x12InitProjectRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"]\n\x13InitProjectResponse\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08relic_id\x18\x03 \x01(\t\x12\x12\n\nrelic_name\x18\x04 \x01(\t\"\xb4\x02\n\x13ListProjectsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x1a\n\x12project_id_or_name\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\r\n\x05limit\x18\x04 \x01(\x03\x12\x31\n\rcreated_after\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x63reated_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rupdated_after\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0eupdated_before\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\":\n\x14ListProjectsResponse\x12\"\n\x08projects\x18\x01 \x03(\x0b\x32\x10.lmao_pb.ProjectB/Z-github.com/NimbleBoxAI/nimblebox-lmao/lmao_pbb\x06proto3')



_PROJECT = DESCRIPTOR.message_types_by_name['Project']
_INITPROJECTREQUEST = DESCRIPTOR.message_types_by_name['InitProjectRequest']
_INITPROJECTRESPONSE = DESCRIPTOR.message_types_by_name['InitProjectResponse']
_LISTPROJECTSREQUEST = DESCRIPTOR.message_types_by_name['ListProjectsRequest']
_LISTPROJECTSRESPONSE = DESCRIPTOR.message_types_by_name['ListProjectsResponse']
Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), {
  'DESCRIPTOR' : _PROJECT,
  '__module__' : 'project_pb2'
  # @@protoc_insertion_point(class_scope:lmao_pb.Project)
  })
_sym_db.RegisterMessage(Project)

InitProjectRequest = _reflection.GeneratedProtocolMessageType('InitProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITPROJECTREQUEST,
  '__module__' : 'project_pb2'
  # @@protoc_insertion_point(class_scope:lmao_pb.InitProjectRequest)
  })
_sym_db.RegisterMessage(InitProjectRequest)

InitProjectResponse = _reflection.GeneratedProtocolMessageType('InitProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITPROJECTRESPONSE,
  '__module__' : 'project_pb2'
  # @@protoc_insertion_point(class_scope:lmao_pb.InitProjectResponse)
  })
_sym_db.RegisterMessage(InitProjectResponse)

ListProjectsRequest = _reflection.GeneratedProtocolMessageType('ListProjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSREQUEST,
  '__module__' : 'project_pb2'
  # @@protoc_insertion_point(class_scope:lmao_pb.ListProjectsRequest)
  })
_sym_db.RegisterMessage(ListProjectsRequest)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSRESPONSE,
  '__module__' : 'project_pb2'
  # @@protoc_insertion_point(class_scope:lmao_pb.ListProjectsResponse)
  })
_sym_db.RegisterMessage(ListProjectsResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/NimbleBoxAI/nimblebox-lmao/lmao_pb'
  _PROJECT._serialized_start=90
  _PROJECT._serialized_end=413
  _INITPROJECTREQUEST._serialized_start=415
  _INITPROJECTREQUEST._serialized_end=457
  _INITPROJECTRESPONSE._serialized_start=459
  _INITPROJECTRESPONSE._serialized_end=552
  _LISTPROJECTSREQUEST._serialized_start=555
  _LISTPROJECTSREQUEST._serialized_end=863
  _LISTPROJECTSRESPONSE._serialized_start=865
  _LISTPROJECTSRESPONSE._serialized_end=923
# @@protoc_insertion_point(module_scope)
